@@ -1,13 +1,7 @@
-import sys
-import os
-import time
-import datetime as dt
+import importlib.metadata
 
 import alabaster
 
-sys.path.insert(0, os.path.abspath(os.path.join("..", "src")))
-import marshmallow  # noqa: E402
-
 extensions = [
     "sphinx.ext.autodoc",
     "sphinx.ext.intersphinx",
@@ -27,22 +21,13 @@ issues_github_path = "marshmallow-code/marshmallow"
 
 templates_path = ["_templates"]
 
-# Use SOURCE_DATE_EPOCH for reproducible build output https://reproducible-builds.org/docs/source-date-epoch/
-build_date = dt.datetime.utcfromtimestamp(
-    int(os.environ.get("SOURCE_DATE_EPOCH", time.time()))
-)
-
 source_suffix = ".rst"
 master_doc = "index"
 
 project = "marshmallow"
-copyright = (
-    ' {:%Y} <a href="https://stevenloria.com">Steven Loria</a> and contributors'.format(
-        build_date
-    )
-)
+copyright = '<a href="https://stevenloria.com">Steven Loria</a> and contributors'
 
-version = release = marshmallow.__version__
+version = release = importlib.metadata.version("marshmallow")
 
 exclude_patterns = ["_build"]
 
@@ -51,13 +36,12 @@ exclude_patterns = ["_build"]
 html_theme_path = [alabaster.get_path()]
 html_theme = "alabaster"
 html_static_path = ["_static"]
-html_css_files = ["css/versionwarning.css"]
+html_css_files = ["css/versionwarning.css", "css/sponsor-message.css"]
 templates_path = ["_templates"]
 html_show_sourcelink = False
 
 html_theme_options = {
     "logo": "marshmallow-logo.png",
-    "logo_name": None,
     "description": "Object serialization and deserialization, lightweight and fluffy.",
     "description_font_style": "italic",
     "github_user": "marshmallow-code",
@@ -74,7 +58,7 @@ html_theme_options = {
     "warn_border": "#EEE",
     # Used to populate the useful-links.html template
     "extra_nav_links": {
-        "marshmallow @ PyPI": "https://pypi.python.org/pypi/marshmallow",
+        "marshmallow @ PyPI": "https://pypi.org/project/marshmallow/",
         "marshmallow @ GitHub": "https://github.com/marshmallow-code/marshmallow",
         "Issue Tracker": "https://github.com/marshmallow-code/marshmallow/issues",
         "Ecosystem": "https://github.com/marshmallow-code/marshmallow/wiki/Ecosystem",
